@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: case-insensitive
-version: 0.3.0.1
-id: case-insensitive-0.3.0.1-a89b449b7d7ce6dd6c6d718d8bc83cb5
+version: 0.4.0.1
+id: case-insensitive-0.4.0.1-6ab4ff76a505da904c51cb94c3242e3c
 
 license: BSD3
 copyright: 2011 Bas van Dijk
 maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
 stability:
-homepage:
+homepage: https://github.com/basvandijk/case-insensitive
 package-url:
+synopsis: Case insensitive string comparison
 description: The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
              constructor which can be parameterised by a string-like
              type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
@@ -20,22 +21,23 @@ pkgpath: devel/hs-case-insensitive
 exposed: True
 exposed-modules: Data.CaseInsensitive
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/case-insensitive-0.3.0.1
-library-dirs: /usr/local/lib/ghc/case-insensitive-0.3.0.1
-hs-libraries: HScase-insensitive-0.3.0.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/case-insensitive-0.4.0.1
+library-dirs: /usr/local/lib/ghc/case-insensitive-0.4.0.1
+hs-libraries: HScase-insensitive-0.4.0.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
-         hashable-1.1.2.2-6a4ed2e9867bca45698894dcbd97c792
-         text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
+         hashable-1.1.2.3-1e9e274afb8e07dab57c2a975698461b
+         text-0.11.2.3-6d44323283fc0f3935743a72b4424942
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-case-insensitive-0.3.0.1/html/case-insensitive.haddock
-haddock-html: /usr/local/share/doc/hs-case-insensitive-0.3.0.1/html
+haddock-interfaces: /usr/local/share/doc/hs-case-insensitive-0.4.0.1/html/case-insensitive.haddock
+haddock-html: /usr/local/share/doc/hs-case-insensitive-0.4.0.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
